@@ -48,28 +48,31 @@ class CWWebDriver:
             options.binary_location = self.binary_location
             options.add_argument('--headless') # https://www.ytyng.com/blog/ubuntu-chromedriver/
             options.add_argument("--disable-dev-shm-usage")  # overcome limited resource problems
-            options.add_argument("start-maximized")  # open Browser in maximized mode
-            options.add_argument("disable-infobars")  # disabling infobars
+            #options.add_argument("start-maximized")  # open Browser in maximized mode
+            options.add_argument("--window-size=1280x651")
+            options.add_argument("--disable-infobars")  # disabling infobars
             options.add_argument("--disable-extensions")  # disabling extensions
             options.add_argument("--disable-gpu")  # applicable to windows os only
             options.add_argument("--no-sandbox")  # Bypass OS security model
         elif self.execution_env == EXECUTION_ENV.AWS_LAMBDA:
-            os.environ['HOME'] = '/opt/browser/'
             self.executable_path = "/opt/browser/chromedriver"
-            options.binary_location = "/opt/browser/headless-chromium"
+            options.binary_location = "/opt/browser/chrome-linux/chrome"
             options.add_argument("--headless")
             options.add_argument("--no-sandbox")
             options.add_argument("--single-process")
             options.add_argument("--disable-gpu")
-            options.add_argument("--window-size=1280x1696")
+            options.add_argument("--window-size=1280x651")
             options.add_argument("--disable-application-cache")
             options.add_argument("--disable-infobars")
-            options.add_argument("--hide-scrollbars")
+            #options.add_argument("--hide-scrollbars")
+            options.add_argument("--disable-extensions")  # disabling extensions
             options.add_argument("--enable-logging")
             options.add_argument("--log-level=0")
             options.add_argument("--ignore-certificate-errors")
             options.add_argument("--homedir=/tmp")
             options.add_argument('--disable-dev-shm-usage')
+            # --no-zygote, https://qiita.com/grainrigi/items/3f13b949310b669d08bb
+            options.add_argument('--no-zygote')
         else:
             options.binary_location = self.binary_location
         if self.proxy:
@@ -91,6 +94,9 @@ class CWWebDriver:
         self.driver = webdriver.Chrome(options=options, executable_path=self.executable_path, desired_capabilities=caps)
         self.driver.implicitly_wait(implicitly_wait)
 
+        if device.value.mode == DEVICE_MODE.DESKTOP:
+            self.driver.maximize_window()
+
 
     def __enter__(self):
         """
@@ -113,6 +119,7 @@ class CWWebDriver:
         """[Close WebDriverSession, if chromewebdriver dosen't kill, plsease execute "killall chromedriver"]
         
         """
+        self.driver.close()
         self.driver.quit()
 
     def reload(self):
@@ -240,6 +247,12 @@ class CWWebDriver:
                 scale = 3
             w = inner_width * scale
             #scaled_h = h * scale
+        elif self.execution_env == EXECUTION_ENV.AWS_LAMBDA:
+            if self.device == DEVICE.MOBILE_iPad_Pro or self.device == DEVICE.DESKTOP_GENERAL:
+                scale = 1
+            else:
+                scale = 3
+            w = inner_width * scale
         else:
             if self.device == DEVICE.MOBILE_iPad_Pro or self.device == DEVICE.DESKTOP_GENERAL:
                 scale = 2
@@ -281,6 +294,12 @@ class CWWebDriver:
                 h = (current_location["y"] - prev_location["y"]) * scale - (current_size["height"] / 2)
             else:
                 h = current_location["y"] * scale
+        elif self.execution_env == EXECUTION_ENV.AWS_LAMBDA:
+            if self.device == DEVICE.MOBILE_iPad_Pro or self.device == DEVICE.DESKTOP_GENERAL:
+                scale = 1
+            else:
+                scale = 3
+            w = inner_width * scale
         else:
             if self.device == DEVICE.MOBILE_iPad_Pro or self.device == DEVICE.DESKTOP_GENERAL:
                 scale = 2
